@@ -43,6 +43,7 @@ from .errors import MissingDirError, MissingFileError, BuilderError, \
 from .ipaddresses import IPNetwork, IPAddress
 from .irrdb import IRRDBInfo
 from .cached_objects import CachedObject, normalize_expiry_time
+from .reject_reasons import REJECT_REASONS
 
 
 class ConfigBuilder(object):
@@ -58,24 +59,6 @@ class ConfigBuilder(object):
 
     IGNORABLE_ISSUES = []
 
-    REJECT_REASONS = {
-        "1": "Invalid AS_PATH length",
-        "2": "Prefix is bogon",
-        "3": "Prefix is in global blacklist",
-        "4": "Invalid AFI",
-        "5": "Invalid NEXT_HOP",
-        "6": "Invalid left-most ASN",
-        "7": "Invalid ASN in AS_PATH",
-        "8": "Transit-free ASN in AS_PATH",
-        "9": "Origin ASN not in IRRDB AS-SETs",
-        "10": "IPv6 prefix not in global unicast space",
-        "11": "Prefix is in client blacklist",
-        "12": "Prefix not in IRRDB AS-SETs",
-        "13": "Invalid prefix length",
-        "14": "RPKI INVALID route",
-        "15": "Never via route-servers ASN in AS_PATH",
-    }
-
     def validate_bgpspeaker_specific_configuration(self):
         """Check compatibility between config and target BGP speaker
 
@@ -607,7 +590,8 @@ class ConfigBuilder(object):
         self.data["rtt_based_functions_are_used"] = \
             self.cfg_general.rtt_based_functions_are_used
         self.data["perform_graceful_shutdown"] = self.perform_graceful_shutdown
-        self.data["reject_reasons"] = self.REJECT_REASONS
+        self.data["reject_reasons"] = REJECT_REASONS
+        self.data["any_reject_cause_map_community_set"] = self.cfg_general.any_reject_cause_map_community_set
 
         def ipaddr_ver(ip):
             return IPNetwork(ip).version
@@ -621,6 +605,17 @@ class ConfigBuilder(object):
             prefix = data
             return IPNetwork(prefix).version == ip_ver
 
+        def is_local_file_used(local_file_id):
+            if local_file_id not in self.LOCAL_FILES_IDS:
+                raise AssertionError(
+                    "Local file ID '{}' is referenced in J2 "
+                    "templates but is not in LOCAL_FILES_IDS.".format(
+                        local_file_id
+                    )
+                )
+            local_files = self.local_files or []
+            return local_file_id in local_files
+
         def include_local_file(local_file_id):
             # The 'rpki_rtr_config' local_file_id is always allowed
             # to be included, because it's referenced directly in
@@ -674,6 +669,7 @@ class ConfigBuilder(object):
         )
         env.tests["current_ipver"] = current_ipver
         env.tests["is_ipver"] = is_ipver
+        env.tests["used_local_file"] = is_local_file_used
         env.filters["community_is_set"] = community_is_set
         env.filters["ipaddr_ver"] = ipaddr_ver
         env.filters["include_local_file"] = include_local_file
@@ -719,7 +715,8 @@ class BIRDConfigBuilder(ConfigBuilder):
             the output configuration. Details: https://arouteserver.readthedocs.io/en/latest/CONFIG.html#bird-hooks
     """
 
-    LOCAL_FILES_IDS = ["header", "header4", "header6",
+    LOCAL_FILES_IDS = ["logging",
+                       "header", "header4", "header6",
                        "footer", "footer4", "footer6",
                        "client", "client4", "client6"]
     LOCAL_FILES_BASE_DIR = "/etc/bird"
@@ -859,7 +856,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     """OpenBGPD configuration builder.
     """
 
-    LOCAL_FILES_IDS = ["header",
+    LOCAL_FILES_IDS = ["logging", "header",
                        "pre-irrdb", "post-irrdb",
                        "pre-clients", "post-clients", "client",
                        "pre-filters", "post-filters",
@@ -867,8 +864,8 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
     AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7",
-                         "6.8"]
-    DEFAULT_VERSION = "6.7"
+                         "6.8", "6.9", "7.0", "7.1"]
+    DEFAULT_VERSION = AVAILABLE_VERSION[-1]
 
     IGNORABLE_ISSUES = ["path_hiding", "transit_free_action",
                         "add_path", "max_prefix_action",
@@ -877,7 +874,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
                         "large_communities", "extended_communities",
                         "graceful_shutdown", "internal_communities",
                         "rpki_roas_as_route_objects_source",
-                        "rpki_roas_source"]
+                        "rpki_roas_source", "path_hiding_69"]
 
     def _include_local_file(self, local_file_id):
         return 'include "{}"\n\n'.format(
@@ -890,16 +887,40 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     def validate_bgpspeaker_specific_configuration(self):
         res = True
 
-        if self.cfg_general["path_hiding"]:
+        if self.cfg_general["path_hiding"] and \
+            version.parse(self.target_version) < version.parse("6.9"):
             if not self.process_bgpspeaker_specific_compatibility_issue(
                 "path_hiding",
                 "The 'path_hiding' general configuration parameter is "
                 "set to True, but the configuration generated by "
-                "ARouteServer for OpenBGPD does not support "
+                "ARouteServer for OpenBGPD < 6.9 does not support "
                 "path-hiding mitigation techniques."
             ):
                 res = False
 
+        if self.cfg_general["path_hiding"] and \
+            version.parse(self.target_version) == version.parse("6.9"):
+            if not self.process_bgpspeaker_specific_compatibility_issue(
+                "path_hiding_69",
+                "The 'path_hiding' general configuration parameter is "
+                "set to True, however, for version 6.9 of OpenBGPD, "
+                "some issues were observed that may affect the security "
+                "and stability of the BGP routing ecosystem: please see "
+                "the docs referenced below, and acknowledge this error "
+                "as reported at the end of this message only if you "
+                "applied the patches or if you strongly believe that "
+                "those issues will not affect your deployment and the "
+                "global stability of the Internet routing.\n"
+                "Information about those issues can be found here:\n"
+                "- 2nd best route not getting withdrawn when 'rde "
+                "evaluate all' is configured "
+                "(https://marc.info/?l=openbsd-tech&m=162011500326166&w=2)\n"
+                "- 2nd best route not advertised when 'rde evaluate all' "
+                "is added and the daemon reloaded "
+                "(https://marc.info/?l=openbsd-tech&m=162021735205669&w=2)"
+            ):
+                res = False
+
         transit_free_action = self.cfg_general["filtering"]["transit_free"]["action"]
         if transit_free_action and transit_free_action != "reject":
             if not self.process_bgpspeaker_specific_compatibility_issue(
@@ -1140,23 +1161,51 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
         use_rpki_roas_as_route_objects_cfg = \
             self.cfg_general["filtering"]["irrdb"]["use_rpki_roas_as_route_objects"]
         if use_rpki_roas_as_route_objects_cfg["enabled"]:
-            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache":
+            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache" and \
+               version.parse(self.target_version) < version.parse("6.9"):
                 if not self.process_bgpspeaker_specific_compatibility_issue(
                     "rpki_roas_as_route_objects_source",
-                    "For OpenBGPD only the 'ripe-rpki-validator-cache' "
+                    "For OpenBGPD < 6.9 only the 'ripe-rpki-validator-cache' "
                     "value is allowed for the 'rpki_roas.source' option."
                 ):
                     res = False
 
         if self.cfg_general.rpki_roas_needed:
-            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache":
+            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache" and \
+               version.parse(self.target_version) < version.parse("6.9"):
                 if not self.process_bgpspeaker_specific_compatibility_issue(
                     "rpki_roas_source",
-                    "For OpenBGPD only the 'ripe-rpki-validator-cache' "
+                    "For OpenBGPD < 6.9 only the 'ripe-rpki-validator-cache' "
                     "value is allowed for the 'rpki_roas.source' option."
                 ):
                     res = False
 
+            if self.cfg_general["rpki_roas"]["source"] == "rtr" and \
+               version.parse(self.target_version) == version.parse("6.9"):
+                if not self.process_bgpspeaker_specific_compatibility_issue(
+                    "rpki_roas_source",
+                    "The general configuration policy has 'rpki_roas.source' "
+                    "set to 'rtr', which means that ROAs will be retrieved "
+                    "using one or more RTR sessions directly configured on "
+                    "the route-server. "
+                    "However, for version 6.9 of OpenBGPD, some issues were "
+                    "observed that may affect the operations: please verify "
+                    "whether these issues are considered relevant for your "
+                    "deployment scenario, and if you believe they are not "
+                    "relevant, or if you patched the daemon to circumvent "
+                    "them, please ignore this error as reported at the end of "
+                    "this message.\n"
+                    "Information about those issues can be found here:\n"
+                    "- 'Invalid argument' error on RTR session establishment "
+                    "(OpenBGPD 6.9p0 portable edition, issue #23 on GitHub "
+                    "https://github.com/openbgpd-portable/openbgpd-portable/"
+                    "issues/23)\n"
+                    "- Blocking `connect()` call that may lead to the daemon "
+                    "to block until the connection times out "
+                    "(https://marc.info/?l=openbsd-tech&m=162005636502085&w=2)"
+                ):
+                    res = False
+
         return res
 
     def enrich_j2_environment(self, env):
