@@ -236,6 +236,32 @@ class ConfigureCommand(ARouteServerCommand):
                             rs_as=rs_as
                         )
 
+        def add_euroix_reject_code_comm(code, lrg=None):
+            # https://www.euro-ix.net/en/forixps/large-bgp-communities/
+
+            if self.answers["daemon"] == "openbgpd" and \
+               version.parse(self.answers["version"]) < version.parse("6.1"):
+                # Euro-IX communities are based on Large BGP Communities, which are
+                # not available in OpenBGPD 6.0 or older.
+                return
+
+            assert isinstance(code, int)
+
+            if self.answers["asn"] > 65535:
+                rs_as = self.answers["comms_asn"]
+            else:
+                rs_as = "rs_as"
+
+            if "reject_cause_map" not in cfg["communities"]:
+                cfg["communities"]["reject_cause_map"] = {}
+
+            if code in cfg["communities"]["reject_cause_map"]:
+                raise ValueError(f"Duplicate code: {code}")
+
+            cfg["communities"]["reject_cause_map"][code] = {
+                "lrg": lrg.replace("RS", str(rs_as))
+            }
+
         res = OrderedDict()
         res["cfg"] = OrderedDict()
         cfg = res["cfg"]
@@ -245,11 +271,21 @@ class ConfigureCommand(ARouteServerCommand):
         cfg["router_id"] = self.answers["router_id"]
 
         if self.answers["daemon"] == "openbgpd":
-            self.notes.append(
-                "For OpenBGPD, path-hiding mitigation techniques are "
-                "not implemented."
-            )
-            cfg["path_hiding"] = False
+            if version.parse(self.answers["version"]) < version.parse("6.9"):
+                self.notes.append(
+                    "For OpenBGPD < 6.9, path-hiding mitigation techniques are "
+                    "not implemented."
+                )
+                cfg["path_hiding"] = False
+            elif version.parse(self.answers["version"]) == version.parse("6.9"):
+                self.notes.append(
+                    "For OpenBGPD 6.9, path-hiding mitigation is available, but "
+                    "it's not automatically configured because of some issues "
+                    "in the implementations of bgpd. "
+                    "Please refer to the CHANGELOG for the release 1.6.0 of "
+                    "ARouteServer for more details."
+                )
+                cfg["path_hiding"] = False
 
         cfg["filtering"] = OrderedDict()
         filtering = cfg["filtering"]
@@ -277,9 +313,8 @@ class ConfigureCommand(ARouteServerCommand):
 
         filtering["transit_free"] = {
             "action": "reject",
-            "asns": [174, 209, 286, 701, 1239, 1299, 2828, 2914,
-                     3257, 3320, 3356, 3549, 5511, 6453, 6461,
-                     6762, 6830, 7018, 12956]
+            "asns": [174, 701, 1299, 2914, 3257, 3320, 3356, 5511,
+                     6453, 6461, 6762, 6830, 7018, 12956]
         }
         filtering["never_via_route_servers"] = {
             "peering_db": True
@@ -349,6 +384,13 @@ class ConfigureCommand(ARouteServerCommand):
             filtering["reject_policy"] = {
                 "policy": "tag_and_reject"
             }
+        else:
+            filtering["reject_policy"] = {
+                "policy": "tag"
+            }
+            self.notes.append(
+                "Rejected routes are kept but not advertised to clients."
+            )
 
         if (
             self.answers["daemon"] == "bird" and \
@@ -378,10 +420,50 @@ class ConfigureCommand(ARouteServerCommand):
 
         cfg["communities"] = OrderedDict()
 
-        if self.answers["daemon"] == "bird":
+        if filtering["reject_policy"]["policy"] in ("tag_and_reject", "tag"):
             add_comm("reject_cause",
                      "65520:dyn_val", "rs_as:65520:dyn_val")
 
+            # 1 == Invalid AS_PATH length == AS path too long
+            add_euroix_reject_code_comm(1, "RS:1101:5")
+
+            # 2 == Prefix is bogon == Bogon Prefix
+            add_euroix_reject_code_comm(2, "RS:1101:3")
+
+            # 3 == Prefix is in global blacklist == <missing>
+
+            # 4 == Invalid AFI == <missing>
+
+            # 5 == Invalid NEXT_HOP == next hop IP != peer IP
+            add_euroix_reject_code_comm(5, "RS:1101:8")
+
+            # 6 == Invalid left-most ASN == as-path.first != peeras
+            add_euroix_reject_code_comm(6, "RS:1101:7")
+
+            # 7 == Invalid ASN in AS_PATH == Bogon AS
+            add_euroix_reject_code_comm(7, "RS:1101:4")
+
+            # 8 == Transit-free ASN in AS_PATH == transit-free ASN in AS-Path
+            add_euroix_reject_code_comm(8, "RS:1101:14")
+
+            # 9 == Origin ASN not in IRRDB AS-SETs == Origin AS not in peer AS-SET
+            add_euroix_reject_code_comm(9, "RS:1101:10")
+
+            # 10 == IPv6 prefix not in global unicast space == Bogon Prefix
+            add_euroix_reject_code_comm(10, "RS:1101:3")
+
+            # 11 == Prefix is in client blacklist == <missing>
+
+            # 12 == Prefix not in IRRDB AS-SETs == IRRDB Prefix not found in AS-SET or aut-num
+            add_euroix_reject_code_comm(12, "RS:1101:9")
+
+            # 13 == Invalid prefix length == <missing, there's only too long/short>
+
+            # 14 == RPKI INVALID route == Prefix is RPKI INVALID
+            add_euroix_reject_code_comm(14, "RS:1101:13")
+
+            # 15 == Never via route-servers ASN in AS_PATH == <missing>
+
         add_comm("prefix_present_in_as_set",
                  "64512:11", "rs_as:64512:11")
         add_comm("prefix_not_present_in_as_set",
@@ -395,26 +477,35 @@ class ConfigureCommand(ARouteServerCommand):
         add_comm("route_validated_via_white_list",
                  "64512:41", "rs_as:64512:41")
 
+        add_comm("rpki_bgp_origin_validation_not_performed",
+                 "64512:50", "rs_as:1000:3")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_valid",
+                 "64512:51", "rs_as:1000:1")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_unknown",
+                 "64512:52", "rs_as:1000:2")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_invalid",
+                 "64512:53", "rs_as:1000:4")  # Euro-IX
+
         add_comm("do_not_announce_to_any",
-                 "0:{rs_as}", "rs_as:0:0")
+                 "0:{rs_as}", "rs_as:0:0")  # Euro-IX
         add_comm("do_not_announce_to_peer",
-                 "0:peer_as", "rs_as:0:peer_as")
+                 "0:peer_as", "rs_as:0:peer_as")  # Euro-IX
         add_comm("announce_to_peer",
-                 "{rs_as}:peer_as", "rs_as:1:peer_as")
+                 "{rs_as}:peer_as", "rs_as:1:peer_as")  # Euro-IX
 
         add_comm("prepend_once_to_any",
-                 "65501:{rs_as}", "rs_as:101:0")
+                 "65501:{rs_as}", "rs_as:101:0")  # Euro-IX
         add_comm("prepend_twice_to_any",
-                 "65502:{rs_as}", "rs_as:102:0")
+                 "65502:{rs_as}", "rs_as:102:0")  # Euro-IX
         add_comm("prepend_thrice_to_any",
-                 "65503:{rs_as}", "rs_as:103:0")
+                 "65503:{rs_as}", "rs_as:103:0")  # Euro-IX
 
         add_comm("prepend_once_to_peer",
-                 "65511:peer_as", "rs_as:101:peer_as")
+                 "65511:peer_as", "rs_as:101:peer_as")  # Euro-IX
         add_comm("prepend_twice_to_peer",
-                 "65512:peer_as", "rs_as:102:peer_as")
+                 "65512:peer_as", "rs_as:102:peer_as")  # Euro-IX
         add_comm("prepend_thrice_to_peer",
-                 "65513:peer_as", "rs_as:103:peer_as")
+                 "65513:peer_as", "rs_as:103:peer_as")  # Euro-IX
 
         add_comm("add_noexport_to_peer",
                  "65281:peer_as", "rs_as:65281:peer_as")
