@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ class ConfigParserProgram(object):
         "cache_dir": "cache",
         "cache_expiry": CachedObject.DEFAULT_EXPIRY,
 
-        "bgpq3_path": "bgpq3",
+        "bgpq3_path": "bgpq4",
         "bgpq3_host": IRRDBInfo.BGPQ3_DEFAULT_HOST,
         "bgpq3_sources": IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
 
@@ -284,7 +284,7 @@ class ConfigParserProgram(object):
                         return False
 
                     if yes_no.lower() == "yes":
-                        self.cp_file(s, bak_path)
+                        self.cp_file(d, bak_path)
                         self.cp_file(s, d)
                         write_title()
                         self.v("OK (backed up and updated)")
