@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +14,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .docker import DockerInstance
-from .instances import InstanceNotRunning
+from .instances import InstanceNotRunning, BGPSpeakerInstance
 
 
-class ExaBGPInstance(DockerInstance):
+class ExaBGPInstance(DockerInstance, BGPSpeakerInstance):
 
     MESSAGE_LOGGING_SUPPORT = False
 
