@@ -59,22 +59,22 @@ class OpenBGPDRoute(Route):
         # rt 64537:10
         # rt 64537:10 rt 64538:20
 
-        next_field_should_be = "rt_soo"
-        rt_soo = ""
+        next_field_should_be_comm_type = True
+        comm_type = ""
         comm = ""
 
-        for part in communities.split(" "):
-            if next_field_should_be == "rt_soo":
-                if part not in ("rt", "soo"):
+        for part in communities.split():
+            if next_field_should_be_comm_type:
+                if part not in ("rt", "soo", "ovs"):
                     raise ValueError(
                         "Error while processing the extended communities "
-                        "string '{}': expected 'rt' or 'soo', but '{}' "
+                        "string '{}': expected 'rt', 'soo' or 'ovs', but '{}' "
                         "found.".format(communities, part)
                     )
-                rt_soo = part
-                next_field_should_be = "comm"
-            elif next_field_should_be == "comm":
-                if ":" not in part:
+                comm_type = part
+                next_field_should_be_comm_type = False
+            else:
+                if comm_type != "ovs" and ":" not in part:
                     raise ValueError(
                         "Error while processing the extended communities "
                         "string '{}': ':' not found in the community '{}' "
@@ -82,16 +82,9 @@ class OpenBGPDRoute(Route):
                     )
                 comm = part
 
-                res.append("{}:{}".format(rt_soo, comm))
+                res.append("{}:{}".format(comm_type, comm))
 
-                next_field_should_be = "rt_soo"
-
-        if next_field_should_be != "rt_soo":
-            raise ValueError(
-                "Error while processing the extended communities "
-                "string '{}': one part of the string remained "
-                "unprocessed.".format(communities)
-            )
+                next_field_should_be_comm_type = True
 
         return res
 
@@ -188,7 +181,7 @@ class OpenBGPDInstance(object):
             if last_line_new_route:
                 raw_as_path = line
                 if "{" in raw_as_path:
-                    # Stripping as_set in strings like this:
+                    # Stripping as_set in strings like this:
                     #   222 333 { 333 333 }
                     as_path = raw_as_path[0:raw_as_path.index("{")].strip()
                     as_set = raw_as_path[raw_as_path.index("{") + 1:-1].strip()
@@ -265,6 +258,9 @@ class OpenBGPDInstance(object):
                 return True
         return False
 
+    def clear_cached_routes(self):
+        self.routes = {}
+
     def get_routes(self, prefix, include_filtered=False, only_best=False):
         if include_filtered and only_best:
             raise Exception("Can't set both include_filtered and only_best")
@@ -412,7 +408,7 @@ class OpenBGPDPortableInstance(OpenBGPDInstance, DockerInstance, BGPSpeakerInsta
         try:
             res = self.run_cmd("bgpctl reload")
         except:
-            pass
+            res = ""
 
         if "request processed" in res:
             time.sleep(5)
@@ -489,8 +485,26 @@ class OpenBGPD68Instance(OpenBGPDClassicInstance):
     BGP_SPEAKER_VERSION = "6.8"
     TARGET_VERSION = "6.8"
 
-OpenBGPDPreviousInstance = OpenBGPD67Instance
-OpenBGPDLatestInstance = OpenBGPD68Instance
+class OpenBGPD69Instance(OpenBGPDClassicInstance):
+
+    VIRSH_DOMAINNAME = "arouteserver_openbgpd69"
+
+    TAG = "openbgpd69"
+
+    BGP_SPEAKER_VERSION = "6.9"
+    TARGET_VERSION = "6.9"
+
+class OpenBGPD70Instance(OpenBGPDClassicInstance):
+
+    VIRSH_DOMAINNAME = "arouteserver_openbgpd70"
+
+    TAG = "openbgpd70"
+
+    BGP_SPEAKER_VERSION = "7.0"
+    TARGET_VERSION = "7.0"
+
+OpenBGPDPreviousInstance = OpenBGPD68Instance
+OpenBGPDLatestInstance = OpenBGPD70Instance
 
 class OpenBGPD65PortableInstance(OpenBGPDPortableInstance):
 
@@ -505,8 +519,7 @@ class OpenBGPD66PortableInstance(OpenBGPDPortableInstance):
     TAG = "openbgpd66p"
 
     BGP_SPEAKER_VERSION = "6.6p0"
-    # TARGET_VERSION not set here because it's assumed to be
-    # the same of the OpenBGPD Latest one.
+    TARGET_VERSION = "6.6"
 
 class OpenBGPD67PortableInstance(OpenBGPDPortableInstance):
 
@@ -515,8 +528,7 @@ class OpenBGPD67PortableInstance(OpenBGPDPortableInstance):
     TAG = "openbgpd67p"
 
     BGP_SPEAKER_VERSION = "6.7p0"
-    # TARGET_VERSION not set here because it's assumed to be
-    # the same of the OpenBGPD Latest one.
+    TARGET_VERSION = "6.7"
 
 class OpenBGPD68PortableInstance(OpenBGPDPortableInstance):
 
@@ -525,7 +537,34 @@ class OpenBGPD68PortableInstance(OpenBGPDPortableInstance):
     TAG = "openbgpd68p"
 
     BGP_SPEAKER_VERSION = "6.8p1"
-    # TARGET_VERSION not set here because it's assumed to be
-    # the same of the OpenBGPD Latest one.
+    TARGET_VERSION = "6.8"
 
-OpenBGPDPortableLatestInstance = OpenBGPD68PortableInstance
+class OpenBGPD69PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:6.9p0-patches"
+
+    TAG = "openbgpd69p"
+
+    BGP_SPEAKER_VERSION = "6.9p0"
+    TARGET_VERSION = "6.9"
+
+class OpenBGPD70PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.0p0"
+
+    TAG = "openbgpd70p"
+
+    BGP_SPEAKER_VERSION = "7.0p0"
+    TARGET_VERSION = "7.0"
+
+class OpenBGPD71PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.1p0"
+
+    TAG = "openbgpd71p"
+
+    BGP_SPEAKER_VERSION = "7.1p0"
+    TARGET_VERSION = "7.1"
+
+OpenBGPDPortablePreviousInstance = OpenBGPD68PortableInstance
+OpenBGPDPortableLatestInstance = OpenBGPD71PortableInstance
